@@ -4,6 +4,16 @@
 
 #include "array.h"
 
+static data_unset *data_integer_copy(const data_unset *s) {
+	data_integer *src = (data_integer *)s;
+	data_integer *ds = data_integer_init();
+
+	buffer_copy_string_buffer(ds->key, src->key);
+	ds->is_index_key = src->is_index_key;
+	ds->value = src->value;
+	return (data_unset *)ds;
+}
+
 static void data_integer_free(data_unset *d) {
 	data_integer *ds = (data_integer *)d;
 	
@@ -28,10 +38,11 @@ static int data_integer_insert_dup(data_unset *dst, data_unset *src) {
 	return 0;
 }
 
-static void data_integer_print(data_unset *d) {
+static void data_integer_print(const data_unset *d, int depth) {
 	data_integer *ds = (data_integer *)d;
-	
-	printf("{%s: %d}", ds->key->ptr, ds->value);	
+	UNUSED(depth);
+
+	fprintf(stderr, "%d", ds->value);
 }
 
 
@@ -43,6 +54,7 @@ data_integer *data_integer_init(void) {
 	ds->key = buffer_init();
 	ds->value = 0;
 	
+	ds->copy = data_integer_copy;
 	ds->free = data_integer_free;
 	ds->reset = data_integer_reset;
 	ds->insert_dup = data_integer_insert_dup;
