@@ -30,6 +30,7 @@ handler_t network_server_handle_fdevent(void *s, void *context, int revents) {
 	server     *srv = (server *)s;
 	server_socket *srv_socket = (server_socket *)context;
 	connection *con;
+	int loops = 0;
 	
 	UNUSED(context);
 	
@@ -40,8 +41,11 @@ handler_t network_server_handle_fdevent(void *s, void *context, int revents) {
 				revents);
 		return HANDLER_ERROR;
 	}
-	
-	while (NULL != (con = connection_accept(srv, srv_socket))) {
+
+	/* accept()s at most 100 connections directly
+	 *
+	 * we jump out after 100 to give the waiting connections a chance */	
+	for (loops = 0; loops < 100 && NULL != (con = connection_accept(srv, srv_socket)); loops++) {
 		handler_t r;
 		
 		connection_state_machine(srv, con);
@@ -438,7 +442,7 @@ int network_write_chunkqueue(server *srv, connection *con, chunkqueue *cq) {
 		return 1;
 	}  
 
-	written = con->bytes_written;
+	written = cq->bytes_out;
 
 #ifdef TCP_CORK	
 	/* Linux: put a cork into the socket as we want to combine the write() calls
@@ -452,20 +456,20 @@ int network_write_chunkqueue(server *srv, connection *con, chunkqueue *cq) {
 	
 	if (srv_socket->is_ssl) {
 #ifdef USE_OPENSSL
-		ret = network_write_chunkqueue_openssl(srv, con, cq);
+		ret = network_write_chunkqueue_openssl(srv, con, con->ssl, cq);
 #endif
 	} else {
 		/* dispatch call */
 #if defined USE_LINUX_SENDFILE
-		ret = network_write_chunkqueue_linuxsendfile(srv, con, cq); 
+		ret = network_write_chunkqueue_linuxsendfile(srv, con, con->fd, cq); 
 #elif defined USE_FREEBSD_SENDFILE
-		ret = network_write_chunkqueue_freebsdsendfile(srv, con, cq); 
+		ret = network_write_chunkqueue_freebsdsendfile(srv, con, con->fd, cq); 
 #elif defined USE_SOLARIS_SENDFILEV
-		ret = network_write_chunkqueue_solarissendfilev(srv, con, cq); 
+		ret = network_write_chunkqueue_solarissendfilev(srv, con, con->fd, cq); 
 #elif defined USE_WRITEV
-		ret = network_write_chunkqueue_writev(srv, con, cq);
+		ret = network_write_chunkqueue_writev(srv, con, con->fd, cq);
 #else
-		ret = network_write_chunkqueue_write(srv, con, cq);
+		ret = network_write_chunkqueue_write(srv, con, con->fd, cq);
 #endif
 	}
 	
@@ -481,7 +485,8 @@ int network_write_chunkqueue(server *srv, connection *con, chunkqueue *cq) {
 	}
 #endif
 
-	written = con->bytes_written - written;
+	written = cq->bytes_out - written;
+	con->bytes_written += written;
 	con->bytes_written_cur_second += written;
 
 	*(con->conf.global_bytes_per_second_cnt_ptr) += written;
