@@ -125,6 +125,7 @@ static server *server_init(void) {
 	CLEAN(errorlog_buf);
 	CLEAN(response_range);
 	CLEAN(tmp_buf);
+	srv->empty_string = buffer_init_string("");
 	CLEAN(cond_check_buf);
 	
 	CLEAN(srvconf.errorlog_file);
@@ -190,6 +191,7 @@ static void server_free(server *srv) {
 	CLEAN(errorlog_buf);
 	CLEAN(response_range);
 	CLEAN(tmp_buf);
+	CLEAN(empty_string);
 	CLEAN(cond_check_buf);
 	
 	CLEAN(srvconf.errorlog_file);
@@ -682,19 +684,24 @@ int main (int argc, char **argv) {
 	}
 	
 	/* dump unused config-keys */
-	for (i = 0; srv->config && i < srv->config->used; i++) {
-		data_unset *du = srv->config->data[i];
-		
-		/* all var.* is known as user defined variable */
-		if (strncmp(du->key->ptr, "var.", sizeof("var.") - 1) == 0) {
-			continue;
-		}
+	for (i = 0; i < srv->config_context->used; i++) {
+		array *config = ((data_config *)srv->config_context->data[i])->value;
+		size_t j;
 
-		if (NULL == array_get_element(srv->config_touched, du->key->ptr)) {
-			log_error_write(srv, __FILE__, __LINE__, "sbs", 
-					"WARNING: unknown config-key:",
-					du->key,
-					"(ignored)");
+		for (j = 0; config && j < config->used; j++) {
+			data_unset *du = config->data[j];
+			
+			/* all var.* is known as user defined variable */
+			if (strncmp(du->key->ptr, "var.", sizeof("var.") - 1) == 0) {
+				continue;
+			}
+
+			if (NULL == array_get_element(srv->config_touched, du->key->ptr)) {
+				log_error_write(srv, __FILE__, __LINE__, "sbs", 
+						"WARNING: unknown config-key:",
+						du->key,
+						"(ignored)");
+			}
 		}
 	}
 	
